import fkeycapture as _f
def get(keycount=1,bytes=False):
  _f.getkey(keycount=1,bytes=False)